pub struct AttemptRunner<H, T = SystemAttemptTimer> { /* private fields */ }Expand description
Runs single-attempt executions by composing handler, timeout, and retry input derivation.
Implementations
Sourceimpl<H> AttemptRunner<H, SystemAttemptTimer>where
H: ExecutorHandler,
impl<H> AttemptRunner<H, SystemAttemptTimer>where
H: ExecutorHandler,
Sourceimpl<H, T> AttemptRunner<H, T>where
H: ExecutorHandler,
T: AttemptTimer,
impl<H, T> AttemptRunner<H, T>where
H: ExecutorHandler,
T: AttemptTimer,
Sourcepub fn with_timer(handler: H, timer: T) -> Self
pub fn with_timer(handler: H, timer: T) -> Self
Creates an attempt runner with an explicit timer implementation.
Sourcepub fn with_timer_and_metrics(
handler: H,
timer: T,
timeout_metrics: TimeoutCooperationMetrics,
) -> Self
pub fn with_timer_and_metrics( handler: H, timer: T, timeout_metrics: TimeoutCooperationMetrics, ) -> Self
Creates an attempt runner with explicit timer and timeout metric sink.
Sourcepub fn with_timer_metrics_and_cadence_policy(
handler: H,
timer: T,
timeout_metrics: TimeoutCooperationMetrics,
timeout_cadence_policy: TimeoutCadencePolicy,
) -> Self
pub fn with_timer_metrics_and_cadence_policy( handler: H, timer: T, timeout_metrics: TimeoutCooperationMetrics, timeout_cadence_policy: TimeoutCadencePolicy, ) -> Self
Creates an attempt runner with explicit timer, metric sink, and cadence policy.
Sourcepub fn timeout_metrics(&self) -> &TimeoutCooperationMetrics
pub fn timeout_metrics(&self) -> &TimeoutCooperationMetrics
Returns the timeout cooperation metric sink used by this runner.
Sourcepub fn timeout_cadence_policy(&self) -> TimeoutCadencePolicy
pub fn timeout_cadence_policy(&self) -> TimeoutCadencePolicy
Returns the timeout cadence policy used by this runner.
Sourcepub fn run_attempt(&self, request: ExecutorRequest) -> AttemptOutcomeRecord
pub fn run_attempt(&self, request: ExecutorRequest) -> AttemptOutcomeRecord
Executes exactly one attempt and returns one terminal attempt outcome record.