Cancellation mechanism for attempt execution.
This module provides cooperative cancellation support for attempt execution. A cancellation token can be checked by handlers to determine if execution should be terminated early.
Structs
- Cancellation
Context - A context that provides access to a cancellation token.
- Cancellation
Token - A token that can be used to signal cancellation to an ongoing operation.