pub struct CancellationContext { /* private fields */ }Expand description
A context that provides access to a cancellation token.
This is passed to handlers to allow them to check for cancellation during execution.
Implementations
Sourceimpl CancellationContext
impl CancellationContext
Sourcepub fn token(&self) -> &CancellationToken
pub fn token(&self) -> &CancellationToken
Returns the cancellation token for this context.
Sourcepub fn was_cancellation_observed(&self) -> bool
pub fn was_cancellation_observed(&self) -> bool
Returns true once any handler poll has observed cancellation.
Sourcepub fn cancellation_observation_latency(&self) -> Option<Duration>
pub fn cancellation_observation_latency(&self) -> Option<Duration>
Returns the first observed cancellation-poll latency from request to observation.