pub enum DispatchQueueError {
Backpressure {
capacity: usize,
},
Shutdown,
}Expand description
Typed errors emitted by DispatchQueue.
Variants
Backpressure
Intake was rejected because the queue reached configured capacity.
Shutdown
Operation was rejected because the dispatch queue has been shut down.