pub fn can_retry(input: &RetryDecisionInput) -> Result<bool, RetryDecisionError>Expand description
Returns whether another attempt may be scheduled from this outcome.
pub fn can_retry(input: &RetryDecisionInput) -> Result<bool, RetryDecisionError>Returns whether another attempt may be scheduled from this outcome.