TimeoutCooperationMetricsSnapshot

Struct TimeoutCooperationMetricsSnapshot 

pub struct TimeoutCooperationMetricsSnapshot {
    pub cooperative: u64,
    pub cooperative_threshold_breach: u64,
    pub non_cooperative: u64,
    pub not_applicable: u64,
}
Snapshot of timeout-cooperation metric counters.

Fields

cooperative: u64

Number of timeout outcomes where cancellation was observed cooperatively.

cooperative_threshold_breach: u64

Number of timeout outcomes where cancellation observation breached cadence threshold.

non_cooperative: u64

Number of timeout outcomes where cancellation was not observed.

not_applicable: u64

Number of outcomes where timeout cooperation did not apply.